from distutils.core import setup

import json

setup(name="json",
      version="3.4",
      description="JSON (http://json.org) reader and writer.",
      author="Patrick D. Logan",
      author_email="patrickdlogan@stardecisions.com",
      url = "http://sourceforge.net/projects/json-py/",
      py_modules=['json']
     )

